import React from 'react';
import styles from './index.less';
import css from 'classnames';
import CloseIcon from './components/close';
import MinimizeIcon from './components/minimize';
import ZoomIcon from './components/zoom';
import logoImg from './assets/logo.png';
import { useModel } from 'umi';
import UserCenter from './components/userCenter';
import system from '@/services/system';
import SvgIcon from '../SvgIcon';
import classNames from 'classnames';
import { CloudDownloadOutlined } from '@ant-design/icons';
import ATooltip from '../Tooltip';
import SyncModal from '../SyncModal';
import { useState } from 'react';
import storage from '@/utils/storage';
import { isClient } from '@/utils/tool';

export default function AppHeader(props) {
  const { className, style } = props;
  const { initialState: { isLogin } = { isLogin: false } } =
    useModel('@@initialState');
  const [modalVisible, setModalVisible] = useState(() => {
    const flag = storage.get('isNotFirstLogin');
    return !flag;
  });

  return (
    <div className={css(styles.appHeader, className)} style={style}>
      <div className={styles.left}>
        <img src={logoImg} alt="" />
      </div>
      <div className={styles.right}>
        {isLogin ? (
          <ATooltip title="同步文件夹至工作空间" placement="bottom">
            <div
              className={classNames(styles.import, styles.mr16)}
              onClick={() => setModalVisible(true)}
            >
              <CloudDownloadOutlined />
            </div>
          </ATooltip>
        ) : null}
        <ATooltip placement="bottom" title="LOCKING 平台">
          <div
            className={classNames(styles.monitor, styles.mr16)}
            onClick={() => system.openUrl('https://www.locking.cn')}
          >
            <SvgIcon xlinkHref="monitor" />
          </div>
        </ATooltip>

        {isLogin ? (
          <>
            <UserCenter className={styles.mr16} />
          </>
        ) : null}
        {isClient ? (
          <>
            <div className={styles.split} />
            <MinimizeIcon
              className={styles.mr12}
              onClick={system.minimizeWindow}
            />
            <ZoomIcon className={styles.mr12} onClick={system.zoomWindow} />
            <CloseIcon className={styles.mr12} onClick={system.closeWindow} />
          </>
        ) : null}
      </div>
      {isLogin ? (
        <SyncModal
          visible={modalVisible}
          onCancel={() => setModalVisible(false)}
          onOk={() => setModalVisible(false)}
        />
      ) : null}
    </div>
  );
}
